@@ -44,16 +44,14 @@ class FileManagerAgent:
         """
             # Start of Selection
         prompt = (
-                "From the provided development plan, build a JSON to add new files to be created and list Existing_files and Context_files as specified in the instruction. Provide only a JSON response without any additional text or Markdown formatting. "
-                "Adding_new_files must include only new files explicitly mentioned in the instruction that need to be created, including all .md files if specified. IMPORTANT: Never skip .md or documentation files like README.md etc. Strictly exclude ALL dependency configuration files (such as requirements.txt, package.json, Podfile, yarn.lock, Gemfile, etc.) from Adding_new_files. These will be handled separately later. For image files, only include .svg files if mentioned. Ignore all png, jpg, jpeg image file types for adding new files. "
+                "From the provided development plan, build a JSON to add new files to be created and list Existing_files as specified in the instruction. Provide only a JSON response without any additional text or Markdown formatting. "
+                "Adding_new_files must include only new files explicitly mentioned in the instruction that need to be created, including all .md files if specified. IMPORTANT: Strictly exclude ALL dependency configuration files (such as requirements.txt, package.json, Podfile, yarn.lock, Gemfile, etc.) from Adding_new_files. These will be handled separately later. For image/asset files, ONLY include .svg files if explicitly mentioned. ALL other image and asset file types (png, jpg, jpeg, gif, ico, mp4, mp3, wav, ogg, ttf, woff, woff2, eot, etc.) MUST be excluded and ignored completely from Adding_new_files - no exceptions. "
                 "Moving_files must include existing files that are explicitly mentioned in the instruction to be moved from a specific location A to a specific location B within the project. Do not include any files in Moving_files unless the instruction clearly states to move an existing file from one location to another."
-                "Existing_files must include only the full paths for file names explicitly mentioned in the instruction that will be updated or modified. "
-                "Context_files must include only the full path context file names explicitly mentioned in the instruction that provide context but won't be modified. Existing_files and Context_files must not overlap. Exclude all dependency files, configuration files, and non-code files such as .gitignore, package.json, Podfile, etc. Focus on including only relevant code files. "
+                "Existing_files must ONLY include files that: 1) Already exist in the project AND 2) Are explicitly mentioned in the instruction as needing direct modifications or updates. Do not include files that are only referenced or mentioned but don't require changes. Each file in Existing_files MUST be one that will have its contents modified. Exclude all image/asset files except .svg files. "
                 "If no file needs to be created or no file needs to be moved, follow this JSON format:\n"
                 "{\n"
                 "    \"Is_creating\": false,\n"
                 "    \"Existing_files\": [\"/full/path/to/file1.extension\", \"/full/path/to/file2.extension\"],\n"
-                "    \"Context_files\": [\"/full/path/to/file3.extension\", \"/full/path/to/file4.extension\"],\n"
                 "    \"Adding_new_files\": []\n"
                 "    \"Moving_files\": []\n"
                 "}\n\n"
@@ -65,7 +63,6 @@ class FileManagerAgent:
                 "    \"commits\": "",\n"
                 "    \"Is_creating\": true,\n"
                 "    \"Existing_files\": [\"/full/path/to/file1.extension\", \"/full/path/to/file2.extension\"],\n"
-                "    \"Context_files\": [\"/full/path/to/file3.extension\", \"/full/path/to/file4.extension\"],\n"
                 "    \"Adding_new_files\": [\n"
                 "        {\n"
                 "            \"Pipeline\": \"1 or 2\",\n"
@@ -86,16 +83,16 @@ class FileManagerAgent:
                 "        }\n"
                 "    ]\n"
                 "}\n\n"
-                "Existing_files, Context_files, and Adding_new_files must include only files explicitly mentioned in the instruction.\n"
+                "Existing_files must ONLY include files that will have their contents directly modified - not just referenced. Adding_new_files must include only files explicitly mentioned in the instruction.\n"
                 "full_path must be the exact path as specified in the development plan, without any modifications. Do not ignore or omit the project folder name (such as projectA, projectB) as it is crucial for the correct path.\n"
                 f"The project root path is \"{self.repo.get_repo_path()}\"\n"
-                "DO NOT CREATE ANY NEW jpg, jpeg, PNG, JPG, JPEG, .ico, OR ANY VIDEO FILE TYPES."
-                "FOR ALL TYPES OF ASSETS, ONLY CREATE AND GENERATE NEW SVG IMAGES."
+                "CRITICAL: For all image and asset files, ONLY .svg files are allowed to be created or added. ALL other image and asset file types (png, jpg, jpeg, gif, ico, mp4, mp3, wav, ogg, ttf, woff, woff2, eot, etc.) MUST be completely excluded and ignored - NO EXCEPTIONS."
                 "CRITICAL: Do NOT include any dependency configuration files in Adding_new_files under any circumstances. These will be handled in a separate process.\n"
                 "IMPORTANT: Strictly adhere to the development plan. For Adding_new_files, never create new paths or folders not explicitly mentioned in the plan. Do not invent or hallucinate any file paths or names. Only include files and paths that are exactly as specified in the development plan, including the project folder name."
                 "Return only valid JSON without Markdown symbols or invalid escapes.\n"
                 "Generate a commit message for the adding/moving files if need. The commit message must use the imperative tense and be structured as follows: <type>: <description>. Use these for <type>: bugfix, feature, optimize, update, config, document, format, restructure, enhance, verify. The commit message should be a single line.\n"
                 "CRITICAL: Do NOT create any new folders standalone. Only create eligible files."
+                "CRITICAL FINAL CHECK: Review all files in Adding_new_files and ensure ONLY .svg files are included for images/assets. Remove ANY other image/asset file types including fonts, audio and video files."
             )
 
         messages = [
@@ -111,7 +108,7 @@ class FileManagerAgent:
 
         try:
             logger.debug("\n #### The `FileManagerAgent` is initiating a request to the AI for file planning")
-            response = await self.ai.prompt(messages, self.max_tokens, 0.2, 0.1)
+            response = await self.ai.prompt(messages, 4096, 0.2, 0.1)
             logger.debug("\n #### The `FileManagerAgent` has successfully received a response from the AI")
             return json.loads(response.choices[0].message.content)
         except json.JSONDecodeError:
@@ -197,7 +194,9 @@ class FileManagerAgent:
             for image_url in assets_link:
                 user_content.append({
                     "type": "image_url",
-                    "image_url": image_url
+                    "image_url": {
+                        "url": image_url
+                    }
                 })
 
         messages = [
@@ -213,7 +212,7 @@ class FileManagerAgent:
 
         try:
             logger.debug("\n #### The `FileManagerAgent` is commencing the process of adding file planning")
-            response = await self.ai.prompt(messages, self.max_tokens, 0.2, 0.1)
+            response = await self.ai.prompt(messages, 4096, 0.2, 0.1)
             logger.debug("\n #### The `FileManagerAgent` has successfully completed the adding file planning process")
             return json.loads(response.choices[0].message.content)
         except json.JSONDecodeError:
@@ -300,7 +299,9 @@ class FileManagerAgent:
             for image_url in assets_link:
                 user_content.append({
                     "type": "image_url",
-                    "image_url": image_url
+                    "image_url": {
+                        "url": image_url
+                    }
                 })
 
         messages = [
@@ -316,7 +317,7 @@ class FileManagerAgent:
 
         try:
             logger.debug("\n #### The `FileManagerAgent` is initiating the process of moving file planning")
-            response = await self.ai.prompt(messages, self.max_tokens, 0.2, 0.1)
+            response = await self.ai.prompt(messages, 4096, 0.2, 0.1)
             logger.debug("\n #### The `FileManagerAgent` has successfully completed the moving file planning process")
             return json.loads(response.choices[0].message.content)
         except json.JSONDecodeError:
