@@ -68,11 +68,6 @@ class RepoMap:
         self.map_processing_time = 0
         self.last_map = None
 
-        if self.verbose:
-            self.io.tool_output(
-                f"RepoMap initialized with map_mul_no_files: {self.map_mul_no_files}"
-            )
-
     def token_count(self, text):
         # len_text = len(text)
         # if len_text < 200:
@@ -128,17 +123,12 @@ class RepoMap:
                 force_refresh,
             )
         except RecursionError:
-            self.io.tool_error("Disabling repo map, git repo too large?")
             self.max_map_tokens = 0
             return
 
         if not files_listing:
             return
 
-        if self.verbose:
-            num_tokens = self.token_count(files_listing)
-            self.io.tool_output(f"Repo-map: {num_tokens / 1024:.1f} k-tokens")
-
         if chat_files:
             other = "other "
         else:
@@ -165,16 +155,11 @@ class RepoMap:
         try:
             self.TAGS_CACHE = Cache(path)
         except sqlite3.OperationalError as e:
-            self.io.tool_error(f"Error accessing tags cache: {e}")
-            self.io.tool_output(f"Attempting to delete and recreate the cache at {path}")
             try:
                 if path.exists():
                     path.unlink()  # Delete the file if it exists
                 self.TAGS_CACHE = Cache(path)  # Try to create a new cache
-                self.io.tool_output("Successfully recreated the tags cache.")
             except Exception as new_e:
-                self.io.tool_error(f"Failed to recreate tags cache: {new_e}")
-                self.io.tool_output("Falling back to in-memory cache.")
                 self.TAGS_CACHE = dict()
 
     def save_tags_cache(self):
@@ -184,7 +169,7 @@ class RepoMap:
         try:
             return os.path.getmtime(fname)
         except FileNotFoundError:
-            self.io.tool_error(f"File not found error: {fname}")
+            return None
 
     def get_tags(self, fname, rel_fname):
         # Check if the file is in the cache and if the modification time has not changed
@@ -261,7 +246,6 @@ class RepoMap:
         try:
             lexer = guess_lexer_for_filename(fname, code)
         except Exception as ex:  # On Windows, bad ref to time.clock which is deprecated?
-            self.io.tool_error(f"Error lexing {fname}: {ex}")
             return
 
         tokens = list(lexer.get_tokens(code))
@@ -297,9 +281,6 @@ class RepoMap:
         personalize = 100 / len(fnames)
 
         if len(fnames) - len(self.TAGS_CACHE) > 100:
-            self.io.tool_output(
-                "Initial repo scan can be slow in larger repos, but only happens once."
-            )
             fnames = tqdm(fnames, desc="Scanning repo")
             showing_bar = True
         else:
@@ -309,15 +290,6 @@ class RepoMap:
             if progress and not showing_bar:
                 progress()
 
-            if not Path(fname).is_file():
-                if fname not in self.warned_files:
-                    if Path(fname).exists():
-                        self.io.tool_error(
-                            f"Repo-map can't include {fname}, it is not a normal file"
-                        )
-                    else:
-                        self.io.tool_error(f"Repo-map can't include {fname}, it no longer exists")
-
                 self.warned_files.add(fname)
                 continue
 
@@ -412,7 +384,6 @@ class RepoMap:
         # dump(ranked_definitions)
 
         for (fname, ident), rank in ranked_definitions:
-            # print(f"{rank:.03f} {fname} {ident}")
             if fname in chat_rel_fnames:
                 continue
             ranked_tags += list(definitions.get((fname, ident), []))
